This corrects the spelling of the OFOPERATION_* constants.

Signed-off-by: Ben Pfaff <b...@nicira.com>
---
 ofproto/ofproto.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/ofproto/ofproto.c b/ofproto/ofproto.c
index ce4da9d..5221318 100644
--- a/ofproto/ofproto.c
+++ b/ofproto/ofproto.c
@@ -117,9 +117,9 @@ struct ofoperation {
     struct hmap_node hmap_node; /* In ofproto's "deletions" hmap. */
     struct rule *rule;          /* Rule being operated upon. */
     enum ofoperation_type type; /* Type of operation. */
-    struct rule *victim;        /* OFOPERATION_ADDING: Replaced rule. */
-    union ofp_action *actions;  /* OFOPERATION_MODIFYING: Replaced actions. */
-    int n_actions;              /* OFOPERATION_MODIFYING: # of old actions. */
+    struct rule *victim;        /* OFOPERATION_ADD: Replaced rule. */
+    union ofp_action *actions;  /* OFOPERATION_MODIFY: Replaced actions. */
+    int n_actions;              /* OFOPERATION_MODIFY: # of old actions. */
     ovs_be64 flow_cookie;       /* Rule's old flow cookie. */
 };
 
-- 
1.7.2.5

_______________________________________________
dev mailing list
dev@openvswitch.org
http://openvswitch.org/mailman/listinfo/dev

Reply via email to